@@ -5,12 +5,14 @@
 import pytest
 import sys
 
+from _pydevd_bundle.pydevd_constants import IS_PY312_OR_GREATER
 from tests import debug
 from tests.debug import runners
 from tests.patterns import some
 
 
 @pytest.mark.parametrize("stop_method", ["breakpoint", "pause"])
+@pytest.mark.skipif(IS_PY312_OR_GREATER, reason="Flakey test on 312 and higher")
 @pytest.mark.parametrize("is_client_connected", ["is_client_connected", ""])
 @pytest.mark.parametrize("wait_for_client", ["wait_for_client", pytest.param("", marks=pytest.mark.skipif(sys.platform.startswith("darwin"), reason="Flakey test on Mac"))])
 def test_attach_api(pyfile, wait_for_client, is_client_connected, stop_method):
@@ -155,6 +157,7 @@ def test_reattach(pyfile, target, run):
     not sys.platform.startswith("linux"),
     reason="https://github.com/microsoft/debugpy/issues/311",
 )
+@pytest.mark.flaky(retries=2, delay=1)
 def test_attach_pid_client(pyfile, target, pid_type):
     @pyfile
     def code_to_debug():
